@@ -1,9 +1,10 @@
 #!/bin/sh
 
 export HOME=$ADTTMP
+export PIP_DISABLE_PIP_VERSION_CHECK=1
 
 pip3 install world
-pip3 list
+pip3 list --format=columns
 ls -ld $HOME/.local/lib/python3.*/site-packages/world-*.dist-info
 pip3 uninstall -y world
-pip3 list
+pip3 list --format=columns
